=========================
StreamSets SDK for Python
=========================

|Version| |Python|

.. |Python| image:: https://shields.io/pypi/pyversions/streamsets.svg?style=flat
    :target: https://pypi.python.org/pypi/streamsets/
    :alt: Python Versions
.. |Version| image:: http://img.shields.io/pypi/v/streamsets.svg?style=flat
    :target: https://pypi.python.org/pypi/streamsets/
    :alt: Package Version

The StreamSets SDK allows users to interact with StreamSets products programmatically using Python, including Control Hub, Data Collector, Transformer, and Transformer for Snowflake.

Notices
-------
Versions 4.0.0 and higher of the StreamSets SDK for Python support the `StreamSets Platform <https://docs.streamsets.com/portal/platform-controlhub/controlhub/UserGuide/GettingStarted/GettingStarted_title.html>`_.
Versions below 4.0.0 support our `Legacy products <https://docs.streamsets.com/portal/controlhub/latest/help/controlhub/UserGuide/GettingStarted/DPM.html#concept_l45_qwf_xw>`_.
Please verify that the version of the SDK you're using is compatible with the StreamSets products you plan to interact with.

Documentation
-------------
.. _documentation:

You can find the latest, most updated documentation on our `documentation portal <https://docs.streamsets.com/>`_, including how to get started with the StreamSets SDK for Python.
For documentation on the StreamSets SDK for Platform, refer to our `Platform SDK documentation <https://docs.streamsets.com/platform-sdk/latest/index.html>`_.
For documentation on the StreamSets SDK for Legacy products, refer to our `Legacy SDK documentation <https://docs.streamsets.com/sdk/latest/index.html>`_.

More Resources
--------------
You can find training and additional resources on the `StreamSets Academy <https://academy.streamsets.com/learn/courses/45/streamsets-sdk-for-python>`_.

You can also find a wealth of knowledge on the `StreamSets Community Forums <https://community.streamsets.com>`_ including product updates, workshops, events and webinars, and more!

Getting Help
------------
Running into issues while using the StreamSets SDK?
Get assistance from `StreamSets Support <https://streamsets.com/support/>`_!

Release Notes
-------------
Release notes for the Platform SDK can be found in the `Platform SDK release notes <https://docs.streamsets.com/platform-sdk/latest/learn/release_notes.html>`_.

Release notes for the Legacy SDK can be found in the `Legacy SDK release notes <https://docs.streamsets.com/sdk/latest/history.html>`_.
